(************************************************************************
 *                                                                      *
 *   Ant Movie Catalog 3.x                                              *
 *   (C) 2000-2006 Antoine Potten                                       *
 *   http://www.antp.be/software                                        *
 *                                                                      *
 ************************************************************************
 *                                                                      *
 *   This program is free software; you can redistribute it and/or      *
 *   modify it under the terms of the GNU General Public License        *
 *   as published by the Free Software Foundation; either version 2     *
 *   of the License, or (at your option) any later version.             *
 *                                                                      *
 *   This program is distributed in the hope that it will be useful,    *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of     *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the      *
 *   GNU General Public License for more details.                       *
 *                                                                      *
 ************************************************************************)

unit import;

interface

uses
  Windows, ImgList, Messages, SysUtils, Classes, Graphics, Controls, Forms,
  Dialogs, ComCtrls, StdCtrls, ExtCtrls, Buttons, shellapi, Menus, ActnList,

  AntCorelButton, AntJvListView, AntStringList, AntJvLinkLabel,
  AntAutoHintLabel, AntJvExControls, AntJvToolEdit,
  TBXDkPanels, TB2Item, TBX,

  MovieClass, base;

{-------------------------------------------------------------------------------
-------------------------------------------------------------------------------}

type

  TImportBDV = function (const AFile: ShortString; Version: Integer; out Error: ShortString): Boolean;
  TImportDivxMgr = function (const AFile: ShortString; Version: Integer; out Error: ShortString): Boolean;
  TGetNextMovie = function (): THandle;

  TImportWin = class(TBaseDlg)
    ImageList1: TImageList;
    Messages: TAntStringList;
    PageControl1: TPageControl;
    TabSheetEmpty: TTabSheet;
    LSelectFormat: TLabel;
    TabSheetCSV: TTabSheet;
    LCSVDelimiter: TLabel;
    LCSVFieldsNames: TLabel;
    ECSVDelimiter: TEdit;
    ECSVField: TComboBox;
    LvCSVPreview: TAntJvListView;
    TabSheet1Col: TTabSheet;
    LvFormat: TListView;
    ActionList1: TActionList;
    ActionListCheck: TAction;
    ActionListUncheck: TAction;
    ActionListAll: TAction;
    ActionListNone: TAction;
    TBPopupMenu1: TTBXPopupMenu;
    TBItem1: TTBXItem;
    TBItem2: TTBXItem;
    TBSeparatorItem1: TTBXSeparatorItem;
    TBItem3: TTBXItem;
    TBItem4: TTBXItem;
    Lv1ColPreview: TAntJvListView;
    LURL: TAntJvLinkLabel;
    PanelCommon: TPanel;
    LSourceFile: TLabel;
    edtSourceFile: TEdit;
    btnBrowse: TTBXButton;
    btnReload: TTBXButton;
    chkAllowDupNumbers: TTBXCheckBox;
    procedure FormCreate(Sender: TObject);
    procedure FormShow(Sender: TObject);
    procedure LvFormatSelectItem(Sender: TObject; Item: TListItem;
      Selected: Boolean);
    procedure btnReloadExecute(Sender: TObject);
    procedure LvCSVPreviewColumnClick(Sender: TObject; Column: TListColumn);
    procedure btnBrowseExecute(Sender: TObject);
    procedure btn3Click(Sender: TObject);
    procedure btn1Click(Sender: TObject);
    procedure FormDestroy(Sender: TObject);
    procedure ActionListCheckExecute(Sender: TObject);
    procedure ActionListAllExecute(Sender: TObject);
    procedure JvListView1Resize(Sender: TObject);
    procedure LURLLinkClick(Sender: TObject; LinkNumber: Integer;
      LinkText: String);
    procedure FormResize(Sender: TObject);

  private
    FMovieList: TMovieList;
    FImportedFile: TFileName;
    FCatalog: TFileName;
    NoFieldDef: Boolean;
    procedure LoadCSV;
    procedure LoadAMC;
    procedure LoadBDV;
    procedure LoadDivxMgr;
    procedure LoadOrigons;
    procedure LoadFromDLL(const FuncImportName: string; DBVersion: Integer = 0);
    procedure RefreshList;

  protected
    procedure LoadOptions; override;
    procedure SaveOptions; override;

  public
    function GetMovies: TMovieList;
    function Execute(const CurrentCatalog: TFileName): TModalResult;
  end;

{-------------------------------------------------------------------------------
-------------------------------------------------------------------------------}

var
  ImportWin: TImportWin;

implementation

{$R *.DFM}

uses
  Math {IfThen},

  Fields, ConstValues, Global, functions_files, ProgramSettings;

const
  msgLoadError      = 0;
  msgImportPictures = 1;
  msgImportPicStore = 2;
  msgImportPicCopy  = 3;
  msgImportPicLink  = 4;
  msgImportPicNone  = 5;
  msgNoFieldDef     = 6;
  msgImportCSV      = 7;
  msgImportAMC      = 8;
  msgImportBDV      = 9;
  msgImportDXM      = 10;
  msgImportOrigons  = 11;

  FromAny     = -1;
  FromCSV     =  0;
  FromAMC     =  1;
  FromBDV     =  2;
  FromDXM     =  3;
  FromOrigons =  4;

  strUrls: array[0..4] of string = (
    '',
    'www.antp.be/software/moviecatalog/',
    'www.basedvdivx.com',
    'www.binaryworks.it/extrememoviemanager',
    'www.origons.com'
  );

{-------------------------------------------------------------------------------
    Options
-------------------------------------------------------------------------------}

procedure TImportWin.LoadOptions;
begin
  with Settings do
  begin
    with rImport do
    begin
      case WindowState of
        1:
          begin
            Self.WindowState := wsNormal;
            Self.Width := WindowWidth;
            Self.Height := WindowHeight;
          end;
        2:
          begin
            Self.WindowState := wsMaximized;
          end;
        else
          begin
            Self.WindowState := wsNormal;
          end;
      end; // case
//      ECSVDelimiter.Text := CSVDelimiter;
//      chkAllowDupNumbers.Checked := AllowDupNumbers;
    end; // with rImport
  end; // with Settings
end;

{-------------------------------------------------------------------------------
-------------------------------------------------------------------------------}

procedure TImportWin.SaveOptions;
begin
  with Settings do
  begin
    with rImport do
    begin
      case Self.WindowState of
        wsNormal:
          begin
            WindowState := 1;
            WindowWidth := Width;
            WindowHeight := Height;
          end;
        wsMaximized:
          begin
            WindowState := 2;
          end;
      end; // case
//      CSVDelimiter := ECSVDelimiter.Text;
//      AllowDupNumbers := chkAllowDupNumbers.Checked;
    end; // with rImport
  end; // with Settings
end;

{-------------------------------------------------------------------------------
  Others
-------------------------------------------------------------------------------}

function TImportWin.GetMovies: TMovieList;
begin
  Result := FMovieList;
end;

{-------------------------------------------------------------------------------
-------------------------------------------------------------------------------}

procedure TImportWin.FormCreate(Sender: TObject);
var
  PageNum: integer;
  field: integer;
begin
  Lv1ColPreview.Columns.Items[1].Width := -2;
  NoFieldDef := True;
  with PageControl1 do
    for PageNum:=0 to PageCount-1 do
      Pages[pagenum].TabVisible:=false;
  with ECSVField.Items do
  begin
    BeginUpdate;
    try
      Add('');
      for field := fieldLow to fieldCount-1  do
        if not (field in VirtualFields) then
          AddObject(strFields[field], Pointer(field+1));
      AddObject(strFieldPicture, Pointer(fieldPicture));
    finally
      EndUpdate;
    end;
  end; // with
  FMovieList := TMovieList.Create;
  btnBrowse.ImageIndex := Ord(ICON_BROWSE);
  btnReload.ImageIndex := Ord(ICON_REFRESH);
  btnBrowse.Images := ToolbarImages;
  btnReload.Images := ToolbarImages;
  inherited;
end;

{-------------------------------------------------------------------------------
-------------------------------------------------------------------------------}

procedure TImportWin.FormDestroy(Sender: TObject);
begin
  FMovieList.Free;
  inherited;
end;

{-------------------------------------------------------------------------------
-------------------------------------------------------------------------------}

procedure TImportWin.FormShow(Sender: TObject);
begin
  inherited;
  LvFormat.SetFocus;
  LvFormat.Selected := nil;
  LvFormatSelectItem(Sender, nil, False);
  FImportedFile := '';
end;

{-------------------------------------------------------------------------------
-------------------------------------------------------------------------------}

procedure TImportWin.LvFormatSelectItem(Sender: TObject; Item: TListItem;
  Selected: Boolean);
begin
  if Selected then
    case LvFormat.ItemIndex of
      FromCSV:
        begin
          btn3.Enabled := LvCSVPreview.Items.Count > 0;
          pagecontrol1.ActivePageIndex := TabSheetCSV.PageIndex;
        end;
      FromAMC,
      FromBDV,
      FromDXM,
      FromOrigons:
        begin
          RefreshList;
          btn3.Enabled := FMovieList.Count > 0;
          pagecontrol1.ActivePageIndex := TabSheet1Col.PageIndex;
          LURL.Caption := Format('<link>%s</link>', [strUrls[LvFormat.ItemIndex]]);
        end;
    else
      begin
        pagecontrol1.ActivePageIndex := 0;
        btn3.Enabled := False;
      end;
    end // case
  else
  begin
    pagecontrol1.ActivePageIndex := 0;
    btn3.Enabled := False;
  end;
end;

{-------------------------------------------------------------------------------
-------------------------------------------------------------------------------}

procedure TImportWin.LoadCSV;
var
  i, colnum: Integer;
  CSVDelimiter: Char;
begin
  NoFieldDef := True;
  if ECSvDelimiter.Text = '' then
    CSVDelimiter := #0
  else
    CSVDelimiter := ECSVDelimiter.Text[1];
  with LvCSVPreview do
  begin
    Items.BeginUpdate;
    try
      Items.Clear;
      Columns.Clear;
      LoadFromCSV(FImportedFile, CSVDelimiter);
      with Items do
      begin
        if Count > 0 then
        begin
          colnum := 0;
          for i := 0 to Count-1 do
            if Item[i].SubItems.Count > colnum then
              colnum := Item[i].SubItems.Count;
          for i := 0 to colnum do // no "-1" since the first column is for the caption and not for a subitem
          with Columns.Add do
            Width := -1;
          for i := 0 to Count-1 do
            Item[i].Checked := True;
        end;
      end;
    finally
      Items.EndUpdate;
    end;
  end; // with
end;

{-------------------------------------------------------------------------------
-------------------------------------------------------------------------------}

procedure TImportWin.LoadAMC;
begin
  try
    if LowerCase(ExtractFileExt(FImportedFile)) = extCatalog[extXML] then
      FMovieList.LoadFromXML(FImportedFile)
    else
      FMovieList.LoadFromFile(FImportedFile);
  except
    on E: Exception do
      MessageWin.Execute(Format(Messages.Strings[msgLoadError], [E.Message]), mtError, [mbOk]);
  end;
  RefreshList;
end;

{-------------------------------------------------------------------------------
-------------------------------------------------------------------------------}

procedure TImportWin.LoadBDV;
begin
  LoadFromDLL('ImportBDV');
  RefreshList;
end;

{-------------------------------------------------------------------------------
-------------------------------------------------------------------------------}

procedure TImportWin.LoadDivxMgr;
begin
  LoadFromDLL('ImportDivxMgr');
  RefreshList;
end;

{-------------------------------------------------------------------------------
-------------------------------------------------------------------------------}

procedure TImportWin.LoadOrigons;
var
  f: TextFile;
  val: string;
  PrevDateFormat: string;
  PrevDateSeparator: Char;
  function GetNextField: string;
  var
    p: Integer;
  begin
    p := Pos(#9, val);
    if p > 0 then
    begin
      Result := Copy(val, 1, p-1);
      Delete(val, 1, p);
    end
    else
    begin
      Result := val;
      val := '';
    end;
  end;
  function ExtractDate(const ADate: string): string;
  begin
    Result := Copy(ADate, 1, Pos(' ', ADate) - 1);
  end;
begin
  PrevDateFormat := ShortDateFormat;
  PrevDateSeparator := DateSeparator;
  ShortDateFormat := 'yyyy/MM/dd';
  DateSeparator := '-';
  try
    FMovieList.Clear;
    AssignFile(f, FImportedFile);
    FileMode := fmOpenRead;
    Reset(f);
    Readln(f, val);
    if Pos('Export 1.0', val) = 0 then
      raise Exception.Create('Unexpected version number. Header found: ' + val);
    Readln(f, val);
    while not Eof(f) do
    begin
      Readln(f, val);
      with FMovieList.Add do
      begin
        Assign(Settings.rOptions.rMovieInformation.rDefaultMovie.Values);
        strOriginalTitle := GetNextField;
        strDescription := StringReplace(GetNextField, ';', #13#10, [rfReplaceAll]);
        strVideoFormat := GetNextField;
        strSource := GetNextField;
        iDisks := StrToIntDef(GetNextField, 1);
        strSize := GetNextField;
        strComments := 'Released by: ' + GetNextField;
        strResolution := GetNextField;
        strCategory := GetNextField;
        strLanguages := GetNextField;
        iYear := StrToIntDef(GetNextField, -1);
        strURL := 'http://us.imdb.com/Title?' + GetNextField;
        strComments := strComments + #13#10 + StringReplace(GetNextField, ';', #13#10, [rfReplaceAll]) + #13#10 + 'OMDb number: ' + GetNextField;
        SetFieldValue(fieldDate, ExtractDate(GetNextField));
      end;
    end;
    CloseFile(f);
  finally
    ShortDateFormat := PrevDateFormat;
    DateSeparator := PrevDateSeparator;
  end;
  RefreshList;
end;

{-------------------------------------------------------------------------------
-------------------------------------------------------------------------------}

procedure TImportWin.LoadFromDLL(const FuncImportName: string; DBVersion: Integer = 0);
var
  FuncImport: TImportBDV;
  FuncNextMovie: TGetNextMovie;
  hDLL, DataHandle: THandle;
  NewMovie: TMovie;
  TempStr: ShortString;
begin
  FMovieList.Clear;
  try
    hDLL := LoadLibrary(PChar(strDirApp + strFileExchangeDLL));
    try
      if hDLL = 0 then
        RaiseLastOSError;
      @FuncImport := GetProcAddress(hDLL, PChar(FuncImportName));
      if (@FuncImport = nil) then
        RaiseLastOSError;
      @FuncNextMovie := GetProcAddress(hDLL, 'GetNextMovie');
      if (@FuncNextMovie = nil) then
        RaiseLastOSError;
      if FuncImport(ShortString(FImportedFile), DBVersion, TempStr) then
      begin
        DataHandle := FuncNextMovie;
        while DataHandle <> 0 do
        begin
          NewMovie := TMovie.Create;
          NewMovie.LoadFromMemory(DataHandle);
          FMovieList.Add(NewMovie);
          DataHandle := FuncNextMovie;
        end;
      end else
        raise Exception.Create(TempStr);
    finally
      FreeLibrary(hDLL);
    end;
  except
    on E: Exception do
      MessageWin.Execute(Format(Messages.Strings[msgLoadError], [E.Message]), mtError, [mbOk]);
  end;
end;

{-------------------------------------------------------------------------------
-------------------------------------------------------------------------------}

procedure TImportWin.btnReloadExecute(Sender: TObject);
begin
  FImportedFile := edtSourceFile.Text;
  if FileExists(FImportedFile) and (LvFormat.Selected <> nil) then
  begin
    ImportWin.Enabled := False;
    Cursor := crHourGlass;
    try
      case LvFormat.Selected.Index of
        FromCSV: LoadCSV;
        FromAMC: LoadAMC;
        FromBDV: LoadBDV;
        FromDXM: LoadDivxMgr;
        FromOrigons: LoadOrigons;
      end; // case
    finally
      Cursor := crDefault;
      ImportWin.Enabled := True;
    end; // try
    LvFormatSelectItem(Sender, LvFormat.Selected, LvFormat.Selected <> nil);
  end else
    FImportedFile := '';
end;

{-------------------------------------------------------------------------------
-------------------------------------------------------------------------------}

procedure TImportWin.LvCSVPreviewColumnClick(Sender: TObject; Column: TListColumn);
var
  f: Integer;
begin
  if ECSVField.ItemIndex = -1 then
    Exit;
  f := Integer(ECSVField.Items.Objects[ECSVField.ItemIndex]);
  if f = fieldPicture then
    Column.Caption := strFieldPicture
  else
  if f-1 in AllFields then
    Column.Caption := strFields[f-1]
  else
    Column.Caption := '';
  NoFieldDef := False;
  Column.Tag := f;
end;

{-------------------------------------------------------------------------------
-------------------------------------------------------------------------------}

procedure TImportWin.btnBrowseExecute(Sender: TObject);
var
  iFormat: integer;
begin
  if LvFormat.Selected = nil then
    iFormat := -1
  else
    iFormat := LvFormat.Selected.Index;
  with TOpenDialog.Create(Self) do
    try
      Options := DialogOpenOptions;
      case iFormat of
        FromCSV:
          begin
            Filter := DialogCSVFilter;
            DefaultExt := 'csv';
            Title := Messages.Strings[msgImportCSV];
          end;
        FromAMC:
          begin
            Filter := DialogCatalogFilter;
            DefaultExt := 'amc';
            Title := Messages.Strings[msgImportAMC];
          end;
        FromBDV:
          begin
            Filter := DialogBDVFilter;
            DefaultExt := 'bdv';
            Title := Messages.Strings[msgImportBDV];
          end;
        FromDXM:
          begin
            Filter := DialogDivxMgrFilter;
            DefaultExt := 'mdb';
            Title := Messages.Strings[msgImportDXM];
          end;
        FromOrigons:
          begin
            Filter := DialogOrigonsFilter;
            DefaultExt := '';
            Title := Messages.Strings[msgImportOrigons];
          end;
      else // FromAny:
          begin
            Filter := '';
            DefaultExt := '';
            Title := Self.Caption;
          end;
      end;
      InitialDir := Settings.rOptions.rFolders[fuImport].Value;
      FileName := '';
      if Execute then
      begin
        Settings.rOptions.rFolders[fuImport].Value := ExtractFilePath(FileName);
        edtSourceFile.Text := FileName;
        btnReload.Click;
      end;
    finally
      Free;
    end;
end;

{-------------------------------------------------------------------------------
-------------------------------------------------------------------------------}

procedure TImportWin.btn3Click(Sender: TObject);
var
  i, j: Integer;
  NewMovie: TMovie;
  Field, Value, Path: string;
begin
  if LvFormat.Selected <> nil then
  begin
    case LvFormat.ItemIndex of
      FromCSV:
        begin
          if NoFieldDef then
            if MessageWin.Execute(Messages.Strings[msgNoFieldDef], mtWarning, [mbOk, mbCancel]) <> 1 then
            begin
              if ECSVField.CanFocus then
                ECSVField.SetFocus;
              Exit;
            end;
          with LvCSVPreview do
            for i := 0 to Items.Count-1 do
              if Items.Item[i].Checked then
              begin
                NewMovie := TMovie.Create;
                NewMovie.InitFields;
                for j := 0 to Min(Columns.Count-1, Items.Item[i].SubItems.Count) do
                begin
                  Field := Columns.Items[j].Caption;
                  if Field <> '' then
                  begin
                    if j = 0 then
                      Value := Items.Item[i].Caption
                    else
                      Value := Items.Item[i].SubItems.Strings[j-1];
                    NewMovie.SetFieldValue(Field, Value);
                  end; // if
                end; // for j
                FMovieList.Add(NewMovie);
              end; // if checked
        end;
      FromAMC,
      FromBDV,
      FromDXM,
      FromOrigons:
        begin
          with Lv1ColPreview.Items do
            for i := 0 to Count-1 do
              if not Item[i].Checked then
              begin
                FMovieList.Remove(Item[i].Data);
              end;
        end;
    end;
    if (LvFormat.ItemIndex in [FromBDV, FromDXM, FromCSV]) and (FMovieList.HasImages(False, True, True)) then
    begin
      MessageWin.btn2.Enabled := FCatalog <> ''; // not very clean, but it works
      try
        Path := ExtractFilePath(FImportedFile);
        case LvFormat.ItemIndex of
          FromBDV,
          FromCSV: SetCurrentDir(Path);
          FromDXM: SetCurrentDir(ExtractFilePath(ExcludeTrailingPathDelimiter(Path)));
        end;
        Path := ExtractFilePath(FCatalog);
        with Messages do
          case MessageWin.Execute(Strings[msgImportPictures], mtConfirmation,
            [Strings[msgImportPicStore], Strings[msgImportPicCopy], Strings[msgImportPicLink], Strings[msgImportPicNone]]) of
            1:
              begin
                with FMovieList do
                  for i := 0 to Count-1 do
                    with TMovie(Items[i]) do
                      if strPicture <> '' then
                      begin
                        Picture.Free;
                        Picture := TMemoryStream.Create;
                        try
                          Picture.LoadFromFile(strPicture);
                          strPicture := ExtractFileExt(strPicture);
                        except
                          Picture.Free;
                          Picture := nil;
                          strPicture := '';
                        end;
                      end;
              end;
            2:
              begin
                if FCatalog = '' then
                  raise Exception.Create('Unexpected result : no catalog file, cannot copy pictures');
                with FMovieList do
                  for i := 0 to Count-1 do
                    with TMovie(Items[i]) do
                      if strPicture <> '' then
                        strPicture := CopyWithoutOverwrite(strPicture, Path);
              end;
            3:
              begin
                Path := IncludeTrailingPathDelimiter(GetCurrentDir);
                with FMovieList do
                  for i := 0 to Count-1 do
                    with TMovie(Items[i]) do
                      if strPicture <> '' then
                        strPicture := Path + strPicture;
              end;
            4:
              begin
                with FMovieList do
                  for i := 0 to Count-1 do
                    with TMovie(Items[i]) do
                      strPicture := '';
              end;
          end;
      finally
        MessageWin.btn2.Enabled := True;
      end;
    end;
    ModalResult := mrOk;
  end;
end;

{-------------------------------------------------------------------------------
-------------------------------------------------------------------------------}

procedure TImportWin.btn1Click(Sender: TObject);
begin
  functions_files.LaunchHelp(HelpContext + LvFormat.ItemIndex + 1);
end;

{-------------------------------------------------------------------------------
-------------------------------------------------------------------------------}

procedure TImportWin.RefreshList;
var
  i: Integer;
begin
  with Lv1ColPreview.Items do
  begin
    BeginUpdate;
    try
      Clear;
      for i := 0 to FMovieList.Count-1 do
        with Add, TMovie(FMovieList.Items[i]) do
        begin
          Caption := IntToStr(iNumber);
          SubItems.Add(GetFormattedTitle);
          Checked := True;
          Data := FMovieList.Items[i];
        end;
    finally
      EndUpdate;
    end;
  end;
end;

{-------------------------------------------------------------------------------
-------------------------------------------------------------------------------}

function TImportWin.Execute(const CurrentCatalog: TFileName): TModalResult;
begin
  FCatalog := CurrentCatalog;
  Result := ShowModal;
end;

{-------------------------------------------------------------------------------
-------------------------------------------------------------------------------}

procedure TImportWin.ActionListCheckExecute(Sender: TObject);
var
  i: Integer;
  bState: Boolean;
  Lv: TListView;
begin
  bState := (Sender = ActionListCheck);
  case LvFormat.Selected.Index of
    FromAMC, FromBDV, FromDXM, FromOrigons:
      Lv := Lv1ColPreview;
    FromCSV:
      Lv := LvCSVPreview;
  else
    Exit;
  end;
  with Lv.Items do
    for i := 0 to Count-1 do
      if Item[i].Selected then
        Item[i].Checked := bState;
end;

{-------------------------------------------------------------------------------
-------------------------------------------------------------------------------}

procedure TImportWin.ActionListAllExecute(Sender: TObject);
var
  i: Integer;
  bState: Boolean;
  Lv: TListView;
begin
  bState := (Sender = ActionListAll);
  case LvFormat.Selected.Index of
    FromAMC, FromBDV, FromDXM, FromOrigons:
      Lv := Lv1ColPreview;
    FromCSV:
      Lv := LvCSVPreview;
  else
    Exit;
  end;
  with Lv.Items do
    for i := 0 to Count-1 do
      Item[i].Checked := bState;
end;

{-------------------------------------------------------------------------------
-------------------------------------------------------------------------------}

procedure TImportWin.JvListView1Resize(Sender: TObject);
begin
  with Lv1ColPreview do
    Columns.Items[1].Width := ClientWidth - Columns.Items[0].Width;
end;

{-------------------------------------------------------------------------------
-------------------------------------------------------------------------------}

procedure TImportWin.LURLLinkClick(Sender: TObject; LinkNumber: Integer; LinkText: String);
begin
  LaunchProg('http://' + LinkText);
end;

{-------------------------------------------------------------------------------
-------------------------------------------------------------------------------}

procedure TImportWin.FormResize(Sender: TObject);
var
  i: Integer;
begin
  inherited;
  i := LvFormat.Width;
  LvFormat.ClientWidth := GetSystemMetrics(SM_CXICONSPACING) + 4;
  i := LvFormat.Width - i;
  PageControl1.Width := PageControl1.Width - i;
  PageControl1.Left := PageControl1.Left + i;
  PanelCommon.Left := LvFormat.Width;
  PanelCommon.Width := ClientWidth - LvFormat.Width;
end;

{-------------------------------------------------------------------------------
-------------------------------------------------------------------------------}

end.
